@@ -3,7 +3,7 @@
  * testephylocationentry.c
  * This file is part of Epiphany
  *
- * Copyright (C) 2008 - Diego Escalante Urrelo
+ * Copyright © 2008 - Diego Escalante Urrelo
  *
  * Epiphany is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
  
 #include "config.h"
 #include "ephy-location-entry.h"
+#include <glib.h>
 #include <gtk/gtk.h>
 
 static void
@@ -141,30 +142,22 @@ main (int argc, char *argv[])
 {
   gtk_test_init (&argc, &argv);
 
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/new",
-    test_entry_new);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/get_entry",
-    test_entry_get_entry);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/set_location",
-    test_entry_set_location);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/get_location",
-    test_entry_get_location);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/set_location_null",
-    test_entry_set_location_null);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/get_location_empty",
-    test_entry_get_location_empty);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/can_undo",
-    test_entry_can_undo);
-  g_test_add_func (
-    "/lib/widgets/ephy-location-entry/can_redo",
-    test_entry_can_redo);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/new",
+                   test_entry_new);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/get_entry",
+                   test_entry_get_entry);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/set_location",
+                   test_entry_set_location);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/get_location",
+                   test_entry_get_location);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/set_location_null",
+                   test_entry_set_location_null);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/get_location_empty",
+                   test_entry_get_location_empty);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/can_undo",
+                   test_entry_can_undo);
+  g_test_add_func ("/lib/widgets/ephy-location-entry/can_redo",
+                   test_entry_can_redo);
 
   return g_test_run ();
 }
